# Getting Started

## What is QuGradLab
An extension to the Python package [QuGrad](https://QuGrad.readthedocs.io) that
implements common Hilbert space structures, Hamiltonians, and pulse shapes for
quantum control.

## Installation

```{include} ../../README.md
:start-after: "## Installation"
:end-before: "## Documentation"
```

---
[Previous](overview.md) | [Next](running_tests.md)